
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.27.5',
    'branch_nick': 'release-1.27',
    'revision_id': 'f970c608c376b4cc51986b08dd1970de236998c3',
    'revno': 11222
}
